@@ -64,4 +64,4 @@ def readJson(dataFile, jsonFile):
     showStats(original_dataDF, dataDF)
 
     #dataDF = dataDF.drop(columns=dataDF.columns[0], axis=1, inplace=True)
-    writeDF(dataDF, json_file['new_file_route'], json_file['new_fileName'], json_file['output_format'])
+    writeDF(dataDF, json_file['new_file_route'], json_file['new_fileName'], json_file['output_format'], json_file['index'])
