@@ -30,10 +30,10 @@ def showStats(original_df, actual_df):
 
 
 
-def writeDF(df, route, name, output_format):
+def writeDF(df, route, name, output_format, index_format):
     if output_format == "csv" or output_format == "txt":
-        df.to_csv(route + name + "." + output_format, index=False)
+        df.to_csv(route + name + "." + output_format, index=index_format)
     elif output_format == "orc":
-        df.to_orc(route + name + "." + output_format, index=False)
+        df.to_orc(route + name + "." + output_format, index=index_format)
     elif output_format == "parquet":
-        df.to_parquet(route + name + "." + output_format, index=False)
+        df.to_parquet(route + name + "." + output_format, index=index_format)
