@@ -48,3 +48,6 @@ def checkJSONFormat(json_file, cols, col_types):
     elif json_file['balance_params']["y_col"] not in cols and json_file['balance_data'] == "yes":
         print("ERROR in JSON: the column you want to use as y_col doesn't exist on the dataset")
         sys.exit(1)
+    elif json_file['index'] not in accepted_header:
+        print("ERROR in JSON: index is not an accepted value")
+    sys.exit(1)
